==> Paws-0.41.tar.gz: Paws-0.41/lib/Paws/DeviceFarm/StopJob.pm <==

package Paws::DeviceFarm::StopJob;
  use Moose;
  has Arn => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'arn' , required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'StopJob');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::DeviceFarm::StopJobResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::DeviceFarm::StopJob - Arguments for method StopJob on L<Paws::DeviceFarm>

=head1 DESCRIPTION

This class represents the parameters used for calling the method StopJob on the
L<AWS Device Farm|Paws::DeviceFarm> service. Use the attributes of this class
as arguments to method StopJob.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to StopJob.

=head1 SYNOPSIS

    my $devicefarm = Paws->service('DeviceFarm');
    my $StopJobResult = $devicefarm->StopJob(
      Arn => 'MyAmazonResourceName',

    );

    # Results:
    my $Job = $StopJobResult->Job;

    # Returns a L<Paws::DeviceFarm::StopJobResult> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/devicefarm/StopJob>

=head1 ATTRIBUTES


=head2 B<REQUIRED> Arn => Str

Represents the Amazon Resource Name (ARN) of the Device Farm job you
wish to stop.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method StopJob in L<Paws::DeviceFarm>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

==> Paws-0.45.tar.gz: Paws-0.45/lib/Paws/DeviceFarm/StopJob.pm <==

package Paws::DeviceFarm::StopJob;
  use Moose;
  has Arn => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'arn' , required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'StopJob');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::DeviceFarm::StopJobResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::DeviceFarm::StopJob - Arguments for method StopJob on L<Paws::DeviceFarm>

=head1 DESCRIPTION

This class represents the parameters used for calling the method StopJob on the
L<AWS Device Farm|Paws::DeviceFarm> service. Use the attributes of this class
as arguments to method StopJob.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to StopJob.

=head1 SYNOPSIS

    my $devicefarm = Paws->service('DeviceFarm');
    my $StopJobResult = $devicefarm->StopJob(
      Arn => 'MyAmazonResourceName',

    );

    # Results:
    my $Job = $StopJobResult->Job;

    # Returns a L<Paws::DeviceFarm::StopJobResult> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/devicefarm/StopJob>

=head1 ATTRIBUTES


=head2 B<REQUIRED> Arn => Str

Represents the Amazon Resource Name (ARN) of the Device Farm job to
stop.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method StopJob in L<Paws::DeviceFarm>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
